Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(20)

Unified Diff: third_party/WebKit/Source/core/html/HTMLPlugInElement.cpp

Issue 2737713002: Rename updateWidgets to updatePlugins (Closed)
Patch Set: Rename updateWidgets to updatePlugins Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/core/html/HTMLPlugInElement.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/html/HTMLPlugInElement.cpp
diff --git a/third_party/WebKit/Source/core/html/HTMLPlugInElement.cpp b/third_party/WebKit/Source/core/html/HTMLPlugInElement.cpp
index d8f485be9b20a87e607039a07353176e8b9ce195..bfbb296012feaaade90c4753de4f57ca1b2d254c 100644
--- a/third_party/WebKit/Source/core/html/HTMLPlugInElement.cpp
+++ b/third_party/WebKit/Source/core/html/HTMLPlugInElement.cpp
@@ -77,11 +77,11 @@ HTMLPlugInElement::HTMLPlugInElement(
PreferPlugInsForImagesOption preferPlugInsForImagesOption)
: HTMLFrameOwnerElement(tagName, doc),
m_isDelayingLoadEvent(false),
// m_needsWidgetUpdate(!createdByParser) allows HTMLObjectElement to delay
// FrameViewBase updates until after all children are parsed. For
// HTMLEmbedElement this delay is unnecessary, but it is simpler to make
// both classes share the same codepath in this class.
- m_needsWidgetUpdate(!createdByParser),
+ m_needsPluginUpdate(!createdByParser),
m_shouldPreferPlugInsForImages(preferPlugInsForImagesOption ==
ShouldPreferPlugInsForImages) {}
@@ -187,7 +187,7 @@ void HTMLPlugInElement::attachLayoutTree(const AttachContext& context) {
if (!m_imageLoader)
m_imageLoader = HTMLImageLoader::create(this);
m_imageLoader->updateFromElement();
- } else if (needsWidgetUpdate() && !layoutEmbeddedItem().isNull() &&
+ } else if (needsPluginUpdate() && !layoutEmbeddedItem().isNull() &&
!layoutEmbeddedItem().showsUnavailablePluginIndicator() &&
!wouldLoadAsNetscapePlugin(m_url, m_serviceType) &&
!m_isDelayingLoadEvent) {
@@ -197,8 +197,8 @@ void HTMLPlugInElement::attachLayoutTree(const AttachContext& context) {
}
}
-void HTMLPlugInElement::updateWidget() {
- updateWidgetInternal();
+void HTMLPlugInElement::updatePlugin() {
+ updatePluginInternal();
if (m_isDelayingLoadEvent) {
m_isDelayingLoadEvent = false;
document().decrementLoadEventDelayCount();
@@ -262,9 +262,10 @@ bool HTMLPlugInElement::shouldAccelerate() const {
void HTMLPlugInElement::detachLayoutTree(const AttachContext& context) {
// Update the FrameViewBase the next time we attach (detaching destroys the
// plugin).
// FIXME: None of this "needsWidgetUpdate" related code looks right.
if (layoutObject() && !useFallbackContent())
- setNeedsWidgetUpdate(true);
+ setNeedsPluginUpdate(true);
+
if (m_isDelayingLoadEvent) {
m_isDelayingLoadEvent = false;
document().decrementLoadEventDelayCount();
@@ -307,7 +308,7 @@ void HTMLPlugInElement::finishParsingChildren() {
if (useFallbackContent())
return;
- setNeedsWidgetUpdate(true);
+ setNeedsPluginUpdate(true);
if (isConnected())
lazyReattachIfNeeded();
}
@@ -648,7 +649,7 @@ bool HTMLPlugInElement::useFallbackContent() const {
}
void HTMLPlugInElement::lazyReattachIfNeeded() {
- if (!useFallbackContent() && needsWidgetUpdate() && layoutObject() &&
+ if (!useFallbackContent() && needsPluginUpdate() && layoutObject() &&
!isImageType()) {
lazyReattachIfAttached();
setPersistedPluginWidget(nullptr);
@@ -77,11 +77,11 @@ HTMLPlugInElement::HTMLPlugInElement(
: HTMLFrameOwnerElement(tagName, doc),
m_isDelayingLoadEvent(false),
- // m_needsWidgetUpdate(!createdByParser) allows HTMLObjectElement to delay
+ // m_needsPluginUpdate(!createdByParser) allows HTMLObjectElement to delay
// FrameViewBase updates until after all children are parsed. For
// HTMLEmbedElement this delay is unnecessary, but it is simpler to make
@@ -262,9 +262,10 @@ bool HTMLPlugInElement::shouldAccelerate() const {
// Update the FrameViewBase the next time we attach (detaching destroys the
// plugin).
- // FIXME: None of this "needsWidgetUpdate" related code looks right.
+ // FIXME: None of this "needsPluginUpdate" related code looks right.
if (layoutObject() && !useFallbackContent())
« no previous file with comments | « third_party/WebKit/Source/core/html/HTMLPlugInElement.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698